==> 2.5.0.zip: cloudlog/application/language/chinese_simplified/menu_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['menu_badge_developer_mode'] = '开发模式';

$lang['menu_logbook'] = '日志簿';
$lang['menu_overview'] = '概览';
$lang['menu_advanced'] = '详细信息';

$lang['menu_qso'] = 'QSO';
$lang['menu_live_qso'] = '添加QSO（从电台获取信息）';
$lang['menu_post_qso'] = '添加QSO（手动输入信息）';
$lang['menu_fast_log_entry'] = "Simple Fast Log Entry";
$lang['menu_live_contest_logging'] = '比赛日志（从电台获取信息）';
$lang['menu_post_contest_logging'] = '比赛日志（手动输入信息）';
$lang['menu_bandmap'] = 'Bandmap';
$lang['menu_view_qsl'] = '浏览QSL卡片';
$lang['menu_view_eqsl'] = '浏览电子QSL卡片';

$lang['menu_notes'] = '笔记';

$lang['menu_analytics'] = '分析';
$lang['menu_statistics'] = '统计';
$lang['menu_gridsquares'] = '网格';
$lang['menu_gridmap'] = '网格地图';
$lang['menu_activated_gridsquares'] = '激活的网格';
$lang['menu_gridsquare_activators'] = '网格激活者';
$lang['menu_distances_worked'] = '距离';
$lang['menu_days_with_qsos'] = '天数';
$lang['menu_timeline'] = '时间线';
$lang['menu_accumulated_statistics'] = '累积统计';
$lang['menu_timeplotter'] = '时间图';
$lang['menu_custom_maps'] = '自定义地图';
$lang['menu_continents'] = '大陆';

$lang['menu_awards'] = '奖项';
$lang['menu_cq'] = 'CQ';
$lang['menu_dok'] = 'DOK';
$lang['menu_dxcc'] = 'DXCC';
$lang['menu_iota'] = 'IOTA';
$lang['menu_pota'] = 'POTA';
$lang['menu_sig'] = 'SIG';
$lang['menu_sota'] = 'SOTA';
$lang['menu_us_counties'] = 'US Counties';
$lang['menu_us_gridmaster'] = 'US Gridmaster';
$lang['menu_vucc'] = 'VUCC';
$lang['menu_was'] = 'WAS';
$lang['menu_wwff'] = 'WWFF';

$lang['menu_admin'] = '管理';
$lang['menu_user_account'] = '用户账户';
$lang['menu_global_options'] = '全局选项';
$lang['menu_modes'] = '模式';
$lang['menu_contests'] = '比赛';
$lang['menu_themes'] = '主题';
$lang['menu_backup'] = '备份';
$lang['menu_update_country_files'] = '更新国家文件';
$lang['menu_debug_information'] = '调试信息';

$lang['menu_search_text'] = '搜索呼号';

$lang['menu_search_button'] = '搜索';
$lang['menu_login_button'] = '登录';

$lang['menu_account'] = '账户';
$lang['menu_station_logbooks'] = '电台站日志簿';
$lang['menu_station_locations'] = '电台站位置';
$lang['menu_bands'] = '波段';
$lang['menu_adif_import_export'] = 'ADIF 导入/导出';
$lang['menu_kml_export'] = 'KML 导出';
$lang['menu_dx_atlas_gridsquare_export'] = 'DX Atlas Gridsquare 导出';
$lang['menu_sota_csv_export'] = 'SOTA CSV 导出';
$lang['menu_cabrillo_export'] = 'Cabrillo 导出';
$lang['menu_oqrs_requests'] = 'OQRS 请求';
$lang['menu_print_requested_qsls'] = '打印请求的QSL卡片';
$lang['menu_labels'] = '标签';
$lang['menu_logbook_of_the_world'] = 'Logbook of the World';
$lang['menu_eqsl_import_export'] = 'eQSL 导入/导出';
$lang['menu_qrz_logbook'] = 'QRZ 日志簿';
$lang['menu_hrd_logbook'] = 'HRDLog 日志簿';
$lang['menu_qo_100_dx_club_upload'] = 'QO-100 Dx Club 上传';
$lang['menu_api_keys'] = 'API 密钥';
$lang['menu_hardware_interfaces'] = '硬件接口';
$lang['menu_help'] = '帮助';
$lang['menu_forum'] = '论坛';
$lang['menu_logout'] = '注销';

$lang['menu_ffma'] = "Fred Fish Memorial Award";
$lang['menu_ja_gridmaster'] = 'JA Gridmaster';
$lang['menu_maintenance']='Maintenance';

==> 2.6.10.zip: cloudlog/application/language/chinese_simplified/menu_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['menu_badge_developer_mode'] = '开发者模式';

$lang['menu_logbook'] = '日志簿';
$lang['menu_overview'] = '概览';
$lang['menu_advanced'] = '详细信息';

$lang['menu_qso'] = 'QSO';
$lang['menu_live_qso'] = '添加QSO（实时）';
$lang['menu_post_qso'] = '添加QSO（手动）';
$lang['menu_fast_log_entry'] = "快速记录QSO";
$lang['menu_live_contest_logging'] = '比赛日志（实时）';
$lang['menu_post_contest_logging'] = '比赛日志（手动）';
$lang['menu_bandmap'] = '波段地图';
$lang['menu_view_qsl'] = '浏览QSL卡片';
$lang['menu_view_eqsl'] = '浏览eQSL卡片';
$lang['menu_view_sstv'] = 'View SSTV Images';

$lang['menu_notes'] = '笔记';

$lang['menu_analytics'] = '分析';
$lang['menu_statistics'] = '统计';
$lang['menu_gridsquares'] = '网格';
$lang['menu_gridmap'] = '网格地图';
$lang['menu_activated_gridsquares'] = '激活的网格';
$lang['menu_gridsquare_activators'] = '网格激活者';
$lang['menu_distances_worked'] = '距离';
$lang['menu_days_with_qsos'] = '天数';
$lang['menu_timeline'] = '时间线';
$lang['menu_accumulated_statistics'] = '累积统计';
$lang['menu_timeplotter'] = '时间图';
$lang['menu_custom_maps'] = '自定义地图';
$lang['menu_continents'] = '大陆';

$lang['menu_awards'] = '奖项';
$lang['menu_cq'] = 'CQ';
$lang['menu_dl_gridmaster'] = 'DL Gridmaster';
$lang['menu_dok'] = 'DOK';
$lang['menu_dxcc'] = 'DXCC';
$lang['menu_iota'] = 'IOTA';
$lang['menu_lx_gridmaster'] = 'LX Gridmaster';
$lang['menu_pota'] = 'POTA';
$lang['menu_sig'] = 'SIG';
$lang['menu_sota'] = 'SOTA';
$lang['menu_us_counties'] = 'US Counties';
$lang['menu_us_gridmaster'] = 'US Gridmaster';
$lang['menu_vucc'] = 'VUCC';
$lang['menu_waja'] = 'WAJA';
$lang['menu_was'] = 'WAS';
$lang['menu_wwff'] = 'WWFF';

$lang['menu_admin'] = '管理';
$lang['menu_user_account'] = '用户账户';
$lang['menu_global_options'] = '全局选项';
$lang['menu_modes'] = '模式';
$lang['menu_contests'] = '比赛';
$lang['menu_themes'] = '主题';
$lang['menu_backup'] = '备份';
$lang['menu_update_country_files'] = '更新国家文件';
$lang['menu_debug_information'] = '调试信息';

$lang['menu_search_text'] = '搜索呼号';
$lang['menu_search_text_quicklog'] = "添加/搜索 呼号";

$lang['menu_search_button'] = '搜索';
$lang['menu_search_button_qicksearch_log'] = "日志";
$lang['menu_login_button'] = '登录';

$lang['menu_account'] = '账户';
$lang['menu_station_logbooks'] = '电台站日志簿';
$lang['menu_station_locations'] = '电台站位置';
$lang['menu_bands'] = '波段';
$lang['menu_adif_import_export'] = 'ADIF 导入/导出';
$lang['menu_kml_export'] = 'KML 导出';
$lang['menu_dx_atlas_gridsquare_export'] = 'DX Atlas Gridsquare 导出';
$lang['menu_sota_csv_export'] = 'SOTA CSV 导出';
$lang['menu_cabrillo_export'] = 'Cabrillo 导出';
$lang['menu_oqrs_requests'] = 'OQRS';
$lang['menu_print_requested_qsls'] = '打印请求的QSL卡片';
$lang['menu_labels'] = '标签';
$lang['menu_logbook_of_the_world'] = 'Logbook of the World';
$lang['menu_eqsl_import_export'] = 'eQSL 导入/导出';
$lang['menu_qrz_logbook'] = 'QRZ 日志簿';
$lang['menu_hrd_logbook'] = 'HRDLog 日志簿';
$lang['menu_qo_100_dx_club_upload'] = 'QO-100 Dx Club 上传';
$lang['menu_api_keys'] = 'API 密钥';
$lang['menu_hardware_interfaces'] = '硬件接口';
$lang['menu_help'] = '帮助';
$lang['menu_forum'] = '论坛';
$lang['menu_logout'] = '注销';

$lang['menu_ffma'] = "弗雷德·菲什纪念奖";
$lang['menu_ja_gridmaster'] = 'JA Gridmaster';
$lang['menu_maintenance']='维护';
